@@ -11,7 +11,7 @@ use POSIX qw(strftime);
 
 use constant DEFAULT_BUFFER_SIZE => 64 * 1024;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 require XSLoader;
 XSLoader::load('Runops::Recorder', $VERSION);
@@ -129,6 +129,17 @@ give it fracitonal seconds.
 
 If you set RR_SKIP_INC the autorun will not show @INC files as the 'a' option does.
 
+=head1 FUNCTIONS
+
+=over 4
+
+=item dump ( $name )
+
+Dumps the buffer as I<$name> in the recording. Adds .dump to the $name if 
+ommited.
+
+=back
+
 =head1 TODO
 
 Record more things such as changes to variables, opened file descriptors etc.
